# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["ObjectUpdateParams"]


class ObjectUpdateParams(TypedDict, total=False):
    id: Required[str]

    filename: str
    """New filename for the document (affects display name and downloads)"""

    metadata: object
    """Additional metadata to merge with existing metadata"""

    path: Optional[str]
    """Folder path for hierarchy preservation (e.g., '/Discovery/Depositions').

    Set to null or empty string to remove.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .template_list_params import TemplateListParams as TemplateListParams
from .template_create_params import TemplateCreateParams as TemplateCreateParams
from .template_list_response import TemplateListResponse as TemplateListResponse
from .template_create_response import TemplateCreateResponse as TemplateCreateResponse
from .template_retrieve_response import TemplateRetrieveResponse as TemplateRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["WorkflowGetStatusParams"]


class WorkflowGetStatusParams(TypedDict, total=False):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]
    """Project ID (for authorization)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .applications import (
    ApplicationsResource,
    AsyncApplicationsResource,
    ApplicationsResourceWithRawResponse,
    AsyncApplicationsResourceWithRawResponse,
    ApplicationsResourceWithStreamingResponse,
    AsyncApplicationsResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "ApplicationsResource",
    "AsyncApplicationsResource",
    "ApplicationsResourceWithRawResponse",
    "AsyncApplicationsResourceWithRawResponse",
    "ApplicationsResourceWithStreamingResponse",
    "AsyncApplicationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ChatDeleteResponse"]


class ChatDeleteResponse(BaseModel):
    id: Optional[str] = None

    cost: Optional[float] = None

    provider: Optional[str] = None

    runtime_id: Optional[str] = FieldInfo(alias="runtimeId", default=None)

    runtime_ms: Optional[int] = FieldInfo(alias="runtimeMs", default=None)

    status: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types import (
    VaultListResponse,
    VaultCreateResponse,
    VaultDeleteResponse,
    VaultIngestResponse,
    VaultSearchResponse,
    VaultUpdateResponse,
    VaultUploadResponse,
    VaultRetrieveResponse,
    VaultConfirmUploadResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestVault:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        vault = client.vault.create(
            name="Contract Review Archive",
        )
        assert_matches_type(VaultCreateResponse, vault, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        vault = client.vault.create(
            name="Contract Review Archive",
            description="Repository for all client contract reviews and analysis",
            enable_graph=True,
            enable_indexing=True,
            group_id="grp_abc123",
            metadata={
                "containsPHI": True,
                "hipaaCompliant": True,
            },
        )
        assert_matches_type(VaultCreateResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.create(
            name="Contract Review Archive",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultCreateResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.create(
            name="Contract Review Archive",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultCreateResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        vault = client.vault.retrieve(
            "vault_abc123",
        )
        assert_matches_type(VaultRetrieveResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.retrieve(
            "vault_abc123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultRetrieveResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.retrieve(
            "vault_abc123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultRetrieveResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_update(self, client: Casedev) -> None:
        vault = client.vault.update(
            id="id",
        )
        assert_matches_type(VaultUpdateResponse, vault, path=["response"])

    @parametrize
    def test_method_update_with_all_params(self, client: Casedev) -> None:
        vault = client.vault.update(
            id="id",
            description="description",
            enable_graph=False,
            group_id="groupId",
            name="Updated Vault Name",
        )
        assert_matches_type(VaultUpdateResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_update(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultUpdateResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_update(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultUpdateResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.update(
                id="",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        vault = client.vault.list()
        assert_matches_type(VaultListResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultListResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultListResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        vault = client.vault.delete(
            id="id",
        )
        assert_matches_type(VaultDeleteResponse, vault, path=["response"])

    @parametrize
    def test_method_delete_with_all_params(self, client: Casedev) -> None:
        vault = client.vault.delete(
            id="id",
            async_=True,
        )
        assert_matches_type(VaultDeleteResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.delete(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultDeleteResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.delete(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultDeleteResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.delete(
                id="",
            )

    @parametrize
    def test_method_confirm_upload_overload_1(self, client: Casedev) -> None:
        vault = client.vault.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
        )
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    def test_method_confirm_upload_with_all_params_overload_1(self, client: Casedev) -> None:
        vault = client.vault.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
            etag="etag",
        )
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_confirm_upload_overload_1(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_confirm_upload_overload_1(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_confirm_upload_overload_1(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.confirm_upload(
                object_id="objectId",
                id="",
                size_bytes=1,
                success=True,
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.with_raw_response.confirm_upload(
                object_id="",
                id="id",
                size_bytes=1,
                success=True,
            )

    @parametrize
    def test_method_confirm_upload_overload_2(self, client: Casedev) -> None:
        vault = client.vault.confirm_upload(
            object_id="objectId",
            id="id",
            error_code="errorCode",
            error_message="errorMessage",
            success=False,
        )
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_confirm_upload_overload_2(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.confirm_upload(
            object_id="objectId",
            id="id",
            error_code="errorCode",
            error_message="errorMessage",
            success=False,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_confirm_upload_overload_2(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.confirm_upload(
            object_id="objectId",
            id="id",
            error_code="errorCode",
            error_message="errorMessage",
            success=False,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_confirm_upload_overload_2(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.confirm_upload(
                object_id="objectId",
                id="",
                error_code="errorCode",
                error_message="errorMessage",
                success=False,
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.with_raw_response.confirm_upload(
                object_id="",
                id="id",
                error_code="errorCode",
                error_message="errorMessage",
                success=False,
            )

    @parametrize
    def test_method_ingest(self, client: Casedev) -> None:
        vault = client.vault.ingest(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(VaultIngestResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_ingest(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.ingest(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultIngestResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_ingest(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.ingest(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultIngestResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_ingest(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.ingest(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.with_raw_response.ingest(
                object_id="",
                id="id",
            )

    @parametrize
    def test_method_search(self, client: Casedev) -> None:
        vault = client.vault.search(
            id="id",
            query="query",
        )
        assert_matches_type(VaultSearchResponse, vault, path=["response"])

    @parametrize
    def test_method_search_with_all_params(self, client: Casedev) -> None:
        vault = client.vault.search(
            id="id",
            query="query",
            filters={"object_id": "string"},
            method="vector",
            top_k=1,
        )
        assert_matches_type(VaultSearchResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_search(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.search(
            id="id",
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultSearchResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_search(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.search(
            id="id",
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultSearchResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_search(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.search(
                id="",
                query="query",
            )

    @parametrize
    def test_method_upload(self, client: Casedev) -> None:
        vault = client.vault.upload(
            id="id",
            content_type="contentType",
            filename="filename",
        )
        assert_matches_type(VaultUploadResponse, vault, path=["response"])

    @parametrize
    def test_method_upload_with_all_params(self, client: Casedev) -> None:
        vault = client.vault.upload(
            id="id",
            content_type="contentType",
            filename="filename",
            auto_index=True,
            metadata={},
            path="path",
            size_bytes=1,
        )
        assert_matches_type(VaultUploadResponse, vault, path=["response"])

    @parametrize
    def test_raw_response_upload(self, client: Casedev) -> None:
        response = client.vault.with_raw_response.upload(
            id="id",
            content_type="contentType",
            filename="filename",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = response.parse()
        assert_matches_type(VaultUploadResponse, vault, path=["response"])

    @parametrize
    def test_streaming_response_upload(self, client: Casedev) -> None:
        with client.vault.with_streaming_response.upload(
            id="id",
            content_type="contentType",
            filename="filename",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = response.parse()
            assert_matches_type(VaultUploadResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_upload(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.with_raw_response.upload(
                id="",
                content_type="contentType",
                filename="filename",
            )


class TestAsyncVault:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.create(
            name="Contract Review Archive",
        )
        assert_matches_type(VaultCreateResponse, vault, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.create(
            name="Contract Review Archive",
            description="Repository for all client contract reviews and analysis",
            enable_graph=True,
            enable_indexing=True,
            group_id="grp_abc123",
            metadata={
                "containsPHI": True,
                "hipaaCompliant": True,
            },
        )
        assert_matches_type(VaultCreateResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.create(
            name="Contract Review Archive",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultCreateResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.create(
            name="Contract Review Archive",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultCreateResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.retrieve(
            "vault_abc123",
        )
        assert_matches_type(VaultRetrieveResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.retrieve(
            "vault_abc123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultRetrieveResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.retrieve(
            "vault_abc123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultRetrieveResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.update(
            id="id",
        )
        assert_matches_type(VaultUpdateResponse, vault, path=["response"])

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.update(
            id="id",
            description="description",
            enable_graph=False,
            group_id="groupId",
            name="Updated Vault Name",
        )
        assert_matches_type(VaultUpdateResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultUpdateResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultUpdateResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.update(
                id="",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.list()
        assert_matches_type(VaultListResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultListResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultListResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.delete(
            id="id",
        )
        assert_matches_type(VaultDeleteResponse, vault, path=["response"])

    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.delete(
            id="id",
            async_=True,
        )
        assert_matches_type(VaultDeleteResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.delete(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultDeleteResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.delete(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultDeleteResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.delete(
                id="",
            )

    @parametrize
    async def test_method_confirm_upload_overload_1(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
        )
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    async def test_method_confirm_upload_with_all_params_overload_1(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
            etag="etag",
        )
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_confirm_upload_overload_1(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_confirm_upload_overload_1(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.confirm_upload(
            object_id="objectId",
            id="id",
            size_bytes=1,
            success=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_confirm_upload_overload_1(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.confirm_upload(
                object_id="objectId",
                id="",
                size_bytes=1,
                success=True,
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.with_raw_response.confirm_upload(
                object_id="",
                id="id",
                size_bytes=1,
                success=True,
            )

    @parametrize
    async def test_method_confirm_upload_overload_2(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.confirm_upload(
            object_id="objectId",
            id="id",
            error_code="errorCode",
            error_message="errorMessage",
            success=False,
        )
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_confirm_upload_overload_2(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.confirm_upload(
            object_id="objectId",
            id="id",
            error_code="errorCode",
            error_message="errorMessage",
            success=False,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_confirm_upload_overload_2(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.confirm_upload(
            object_id="objectId",
            id="id",
            error_code="errorCode",
            error_message="errorMessage",
            success=False,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultConfirmUploadResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_confirm_upload_overload_2(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.confirm_upload(
                object_id="objectId",
                id="",
                error_code="errorCode",
                error_message="errorMessage",
                success=False,
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.with_raw_response.confirm_upload(
                object_id="",
                id="id",
                error_code="errorCode",
                error_message="errorMessage",
                success=False,
            )

    @parametrize
    async def test_method_ingest(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.ingest(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(VaultIngestResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_ingest(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.ingest(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultIngestResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_ingest(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.ingest(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultIngestResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_ingest(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.ingest(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.with_raw_response.ingest(
                object_id="",
                id="id",
            )

    @parametrize
    async def test_method_search(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.search(
            id="id",
            query="query",
        )
        assert_matches_type(VaultSearchResponse, vault, path=["response"])

    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.search(
            id="id",
            query="query",
            filters={"object_id": "string"},
            method="vector",
            top_k=1,
        )
        assert_matches_type(VaultSearchResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_search(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.search(
            id="id",
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultSearchResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.search(
            id="id",
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultSearchResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_search(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.search(
                id="",
                query="query",
            )

    @parametrize
    async def test_method_upload(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.upload(
            id="id",
            content_type="contentType",
            filename="filename",
        )
        assert_matches_type(VaultUploadResponse, vault, path=["response"])

    @parametrize
    async def test_method_upload_with_all_params(self, async_client: AsyncCasedev) -> None:
        vault = await async_client.vault.upload(
            id="id",
            content_type="contentType",
            filename="filename",
            auto_index=True,
            metadata={},
            path="path",
            size_bytes=1,
        )
        assert_matches_type(VaultUploadResponse, vault, path=["response"])

    @parametrize
    async def test_raw_response_upload(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.with_raw_response.upload(
            id="id",
            content_type="contentType",
            filename="filename",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vault = await response.parse()
        assert_matches_type(VaultUploadResponse, vault, path=["response"])

    @parametrize
    async def test_streaming_response_upload(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.with_streaming_response.upload(
            id="id",
            content_type="contentType",
            filename="filename",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vault = await response.parse()
            assert_matches_type(VaultUploadResponse, vault, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_upload(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.with_raw_response.upload(
                id="",
                content_type="contentType",
                filename="filename",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["MemoryListResponse", "Entry", "Meta"]


class Entry(BaseModel):
    id: Optional[str] = None

    content: Optional[str] = None

    created_at: Optional[datetime] = None

    created_by: Optional[str] = None

    source: Optional[str] = None

    tags: Optional[List[str]] = None

    type: Optional[str] = None

    updated_at: Optional[datetime] = None


class Meta(BaseModel):
    chars: Optional[int] = None

    count: Optional[int] = None

    max_chars: Optional[int] = None

    updated_at: Optional[datetime] = None


class MemoryListResponse(BaseModel):
    entries: Optional[List[Entry]] = None

    meta: Optional[Meta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from casedev import Casedev, AsyncCasedev
from casedev._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_annotate(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = client.superdoc.v1.annotate(
            document={},
            fields=[
                {
                    "type": "text",
                    "value": "string",
                }
            ],
        )
        assert v1.is_closed
        assert v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_annotate_with_all_params(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = client.superdoc.v1.annotate(
            document={
                "base64": "base64",
                "url": "url",
            },
            fields=[
                {
                    "type": "text",
                    "value": "string",
                    "id": "id",
                    "group": "group",
                    "options": {
                        "height": 0,
                        "width": 0,
                    },
                }
            ],
            output_format="docx",
        )
        assert v1.is_closed
        assert v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_annotate(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        v1 = client.superdoc.v1.with_raw_response.annotate(
            document={},
            fields=[
                {
                    "type": "text",
                    "value": "string",
                }
            ],
        )

        assert v1.is_closed is True
        assert v1.http_request.headers.get("X-Stainless-Lang") == "python"
        assert v1.json() == {"foo": "bar"}
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_annotate(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.superdoc.v1.with_streaming_response.annotate(
            document={},
            fields=[
                {
                    "type": "text",
                    "value": "string",
                }
            ],
        ) as v1:
            assert not v1.is_closed
            assert v1.http_request.headers.get("X-Stainless-Lang") == "python"

            assert v1.json() == {"foo": "bar"}
            assert cast(Any, v1.is_closed) is True
            assert isinstance(v1, StreamedBinaryAPIResponse)

        assert cast(Any, v1.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_convert(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = client.superdoc.v1.convert(
            from_="docx",
        )
        assert v1.is_closed
        assert v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_convert_with_all_params(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = client.superdoc.v1.convert(
            from_="docx",
            document_base64="document_base64",
            document_url="document_url",
            to="pdf",
        )
        assert v1.is_closed
        assert v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_convert(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        v1 = client.superdoc.v1.with_raw_response.convert(
            from_="docx",
        )

        assert v1.is_closed is True
        assert v1.http_request.headers.get("X-Stainless-Lang") == "python"
        assert v1.json() == {"foo": "bar"}
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_convert(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.superdoc.v1.with_streaming_response.convert(
            from_="docx",
        ) as v1:
            assert not v1.is_closed
            assert v1.http_request.headers.get("X-Stainless-Lang") == "python"

            assert v1.json() == {"foo": "bar"}
            assert cast(Any, v1.is_closed) is True
            assert isinstance(v1, StreamedBinaryAPIResponse)

        assert cast(Any, v1.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_annotate(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = await async_client.superdoc.v1.annotate(
            document={},
            fields=[
                {
                    "type": "text",
                    "value": "string",
                }
            ],
        )
        assert v1.is_closed
        assert await v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_annotate_with_all_params(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = await async_client.superdoc.v1.annotate(
            document={
                "base64": "base64",
                "url": "url",
            },
            fields=[
                {
                    "type": "text",
                    "value": "string",
                    "id": "id",
                    "group": "group",
                    "options": {
                        "height": 0,
                        "width": 0,
                    },
                }
            ],
            output_format="docx",
        )
        assert v1.is_closed
        assert await v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_annotate(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        v1 = await async_client.superdoc.v1.with_raw_response.annotate(
            document={},
            fields=[
                {
                    "type": "text",
                    "value": "string",
                }
            ],
        )

        assert v1.is_closed is True
        assert v1.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await v1.json() == {"foo": "bar"}
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_annotate(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/annotate").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.superdoc.v1.with_streaming_response.annotate(
            document={},
            fields=[
                {
                    "type": "text",
                    "value": "string",
                }
            ],
        ) as v1:
            assert not v1.is_closed
            assert v1.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await v1.json() == {"foo": "bar"}
            assert cast(Any, v1.is_closed) is True
            assert isinstance(v1, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, v1.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_convert(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = await async_client.superdoc.v1.convert(
            from_="docx",
        )
        assert v1.is_closed
        assert await v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_convert_with_all_params(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = await async_client.superdoc.v1.convert(
            from_="docx",
            document_base64="document_base64",
            document_url="document_url",
            to="pdf",
        )
        assert v1.is_closed
        assert await v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_convert(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        v1 = await async_client.superdoc.v1.with_raw_response.convert(
            from_="docx",
        )

        assert v1.is_closed is True
        assert v1.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await v1.json() == {"foo": "bar"}
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_convert(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/superdoc/v1/convert").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.superdoc.v1.with_streaming_response.convert(
            from_="docx",
        ) as v1:
            assert not v1.is_closed
            assert v1.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await v1.json() == {"foo": "bar"}
            assert cast(Any, v1.is_closed) is True
            assert isinstance(v1, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, v1.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ProjectListResponse", "Project", "ProjectLinkedDeployment"]


class ProjectLinkedDeployment(BaseModel):
    id: Optional[str] = None
    """Deployment ID"""

    name: Optional[str] = None
    """Deployment name"""

    type: Optional[Literal["thurgood", "compute"]] = None
    """Type of deployment"""

    url: Optional[str] = None
    """Deployment URL (for Thurgood apps)"""


class Project(BaseModel):
    id: Optional[str] = None
    """Project ID"""

    compute_time_seconds: Optional[float] = FieldInfo(alias="computeTimeSeconds", default=None)
    """Total compute time consumed in seconds"""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Project creation timestamp"""

    description: Optional[str] = None
    """Project description"""

    linked_deployments: Optional[List[ProjectLinkedDeployment]] = FieldInfo(alias="linkedDeployments", default=None)
    """Linked application deployments using this database"""

    name: Optional[str] = None
    """Project name"""

    pg_version: Optional[int] = FieldInfo(alias="pgVersion", default=None)
    """PostgreSQL major version"""

    region: Optional[str] = None
    """AWS region where database is deployed"""

    status: Optional[Literal["active", "suspended", "deleted"]] = None
    """Current project status"""

    storage_size_bytes: Optional[float] = FieldInfo(alias="storageSizeBytes", default=None)
    """Current storage usage in bytes"""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Project last update timestamp"""


class ProjectListResponse(BaseModel):
    projects: List[Project]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["V1DraftParams", "Length"]


class V1DraftParams(TypedDict, total=False):
    instructions: Required[str]
    """What to draft — the core task.

    E.g., "Motion to compel defendant to produce discovery responses"
    """

    vault_id: Required[str]
    """Vault ID where the final document will be uploaded"""

    citations: bool
    """Research and include legal citations"""

    format: Optional[str]
    """Court or jurisdiction formatting hint.

    Triggers a legal-skills search. E.g., "California Superior Court", "SDNY",
    "federal pleading"
    """

    length: Optional[Length]
    """Target document length"""

    model: Optional[str]
    """LLM model override. Defaults to anthropic/claude-sonnet-4.6"""

    object_ids: Optional[SequenceNotStr[str]]
    """Vault object IDs to use as source/reference documents"""

    output_name: Optional[str]
    """Filename for the output document. Auto-generated if omitted."""

    output_type: Literal["pdf", "docx", "xlsx", "pptx", "md"]
    """Output file format"""

    verified: bool
    """
    Verify all citations in a loop — re-run verification and repair bad citations
    until they pass
    """


class Length(TypedDict, total=False):
    """Target document length"""

    target: float
    """Target value (e.g., 2000 words or 5 pages)"""

    unit: Literal["words", "pages"]
    """Whether the target length is measured in words or pages"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VaultConfirmUploadResponse"]


class VaultConfirmUploadResponse(BaseModel):
    already_confirmed: Optional[bool] = FieldInfo(alias="alreadyConfirmed", default=None)

    object_id: Optional[str] = FieldInfo(alias="objectId", default=None)

    status: Optional[Literal["completed", "failed"]] = None

    vault_id: Optional[str] = FieldInfo(alias="vaultId", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["VaultUpdateParams"]


class VaultUpdateParams(TypedDict, total=False):
    description: Optional[str]
    """New description for the vault. Set to null to remove."""

    enable_graph: Annotated[bool, PropertyInfo(alias="enableGraph")]
    """Whether to enable GraphRAG for future document uploads"""

    group_id: Annotated[Optional[str], PropertyInfo(alias="groupId")]
    """
    Move the vault to a different group, or set to null to remove from its current
    group.
    """

    name: str
    """New name for the vault"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.voice import boost_list_extract_params, boost_list_generate_params
from ..._base_client import make_request_options
from ...types.voice.boost_list_extract_response import BoostListExtractResponse
from ...types.voice.boost_list_generate_response import BoostListGenerateResponse

__all__ = ["BoostListResource", "AsyncBoostListResource"]


class BoostListResource(SyncAPIResource):
    """Audio transcription and text-to-speech"""

    @cached_property
    def with_raw_response(self) -> BoostListResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return BoostListResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BoostListResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return BoostListResourceWithStreamingResponse(self)

    def extract(
        self,
        *,
        categories: List[Literal["person", "organization", "legal_term", "medical", "citation", "email"]] | Omit = omit,
        object_ids: SequenceNotStr[str] | Omit = omit,
        text: str | Omit = omit,
        vault_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BoostListExtractResponse:
        """
        Extracts a categorized word boost list from vault documents or raw text using
        LLM entity extraction. The resulting list can be passed as `word_boost` to the
        transcription endpoint for improved accuracy.

        Args:
          categories: Optional filter for entity categories to extract

          object_ids: Object IDs of documents to extract entities from (PDFs, text files)

          text: Raw text input for entity extraction (alternative to vault documents)

          vault_id: Vault ID containing the source documents (use with object_ids)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/voice/boost-list/extract",
            body=maybe_transform(
                {
                    "categories": categories,
                    "object_ids": object_ids,
                    "text": text,
                    "vault_id": vault_id,
                },
                boost_list_extract_params.BoostListExtractParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BoostListExtractResponse,
        )

    def generate(
        self,
        *,
        transcription_job_id: str,
        categories: List[Literal["person", "organization", "legal_term", "medical", "citation", "email"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BoostListGenerateResponse:
        """
        Generates a categorized word boost list from a completed transcription job.
        Extracts entities from the pass-1 transcript for use as `word_boost` in a second
        transcription pass.

        Args:
          transcription_job_id: Completed pass-1 transcription job ID (tr\\__...)

          categories: Optional filter for entity categories to extract

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/voice/boost-list/generate",
            body=maybe_transform(
                {
                    "transcription_job_id": transcription_job_id,
                    "categories": categories,
                },
                boost_list_generate_params.BoostListGenerateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BoostListGenerateResponse,
        )


class AsyncBoostListResource(AsyncAPIResource):
    """Audio transcription and text-to-speech"""

    @cached_property
    def with_raw_response(self) -> AsyncBoostListResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncBoostListResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBoostListResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncBoostListResourceWithStreamingResponse(self)

    async def extract(
        self,
        *,
        categories: List[Literal["person", "organization", "legal_term", "medical", "citation", "email"]] | Omit = omit,
        object_ids: SequenceNotStr[str] | Omit = omit,
        text: str | Omit = omit,
        vault_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BoostListExtractResponse:
        """
        Extracts a categorized word boost list from vault documents or raw text using
        LLM entity extraction. The resulting list can be passed as `word_boost` to the
        transcription endpoint for improved accuracy.

        Args:
          categories: Optional filter for entity categories to extract

          object_ids: Object IDs of documents to extract entities from (PDFs, text files)

          text: Raw text input for entity extraction (alternative to vault documents)

          vault_id: Vault ID containing the source documents (use with object_ids)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/voice/boost-list/extract",
            body=await async_maybe_transform(
                {
                    "categories": categories,
                    "object_ids": object_ids,
                    "text": text,
                    "vault_id": vault_id,
                },
                boost_list_extract_params.BoostListExtractParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BoostListExtractResponse,
        )

    async def generate(
        self,
        *,
        transcription_job_id: str,
        categories: List[Literal["person", "organization", "legal_term", "medical", "citation", "email"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BoostListGenerateResponse:
        """
        Generates a categorized word boost list from a completed transcription job.
        Extracts entities from the pass-1 transcript for use as `word_boost` in a second
        transcription pass.

        Args:
          transcription_job_id: Completed pass-1 transcription job ID (tr\\__...)

          categories: Optional filter for entity categories to extract

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/voice/boost-list/generate",
            body=await async_maybe_transform(
                {
                    "transcription_job_id": transcription_job_id,
                    "categories": categories,
                },
                boost_list_generate_params.BoostListGenerateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BoostListGenerateResponse,
        )


class BoostListResourceWithRawResponse:
    def __init__(self, boost_list: BoostListResource) -> None:
        self._boost_list = boost_list

        self.extract = to_raw_response_wrapper(
            boost_list.extract,
        )
        self.generate = to_raw_response_wrapper(
            boost_list.generate,
        )


class AsyncBoostListResourceWithRawResponse:
    def __init__(self, boost_list: AsyncBoostListResource) -> None:
        self._boost_list = boost_list

        self.extract = async_to_raw_response_wrapper(
            boost_list.extract,
        )
        self.generate = async_to_raw_response_wrapper(
            boost_list.generate,
        )


class BoostListResourceWithStreamingResponse:
    def __init__(self, boost_list: BoostListResource) -> None:
        self._boost_list = boost_list

        self.extract = to_streamed_response_wrapper(
            boost_list.extract,
        )
        self.generate = to_streamed_response_wrapper(
            boost_list.generate,
        )


class AsyncBoostListResourceWithStreamingResponse:
    def __init__(self, boost_list: AsyncBoostListResource) -> None:
        self._boost_list = boost_list

        self.extract = async_to_streamed_response_wrapper(
            boost_list.extract,
        )
        self.generate = async_to_streamed_response_wrapper(
            boost_list.generate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["RunCreateResponse"]


class RunCreateResponse(BaseModel):
    id: Optional[str] = None

    agent_id: Optional[str] = FieldInfo(alias="agentId", default=None)

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)

    object_ids: Optional[List[str]] = FieldInfo(alias="objectIds", default=None)

    status: Optional[Literal["queued"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.applications.v1 import (
    project_list_params,
    project_create_params,
    project_delete_params,
    project_list_env_params,
    project_create_env_params,
    project_create_domain_params,
    project_get_runtime_logs_params,
    project_list_deployments_params,
    project_create_deployment_params,
)
from ....types.applications.v1.project_list_response import ProjectListResponse

__all__ = ["ProjectsResource", "AsyncProjectsResource"]


class ProjectsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ProjectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return ProjectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProjectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return ProjectsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        git_repo: str,
        name: str,
        build_command: str | Omit = omit,
        environment_variables: Iterable[project_create_params.EnvironmentVariable] | Omit = omit,
        framework: str | Omit = omit,
        git_branch: str | Omit = omit,
        install_command: str | Omit = omit,
        output_directory: str | Omit = omit,
        root_directory: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Creates a new application project, validates GitHub access, provisions a default
        case.dev domain, and starts the deployment workflow. The initial response
        returns as soon as the workflow is queued so clients can poll for progress.

        Args:
          git_repo: GitHub repository URL or owner/repo identifier

          name: Human-readable project name

          build_command: Custom build command to override the framework default

          environment_variables: Environment variables to create before the first deployment

          framework: Framework preset for the hosting project, such as nextjs or remix

          git_branch: Git branch to deploy. Defaults to main.

          install_command: Custom install command to override the framework default

          output_directory: Build output directory relative to the project root

          root_directory: Repository subdirectory that contains the app to deploy

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/applications/v1/projects",
            body=maybe_transform(
                {
                    "git_repo": git_repo,
                    "name": name,
                    "build_command": build_command,
                    "environment_variables": environment_variables,
                    "framework": framework,
                    "git_branch": git_branch,
                    "install_command": install_command,
                    "output_directory": output_directory,
                    "root_directory": root_directory,
                },
                project_create_params.ProjectCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Returns project details, domains, and recent deployment information for one
        application project or deployed Thurgood app. Use this endpoint when you need a
        single record with hosting metadata for a details view.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/applications/v1/projects/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        enrich: bool | Omit = omit,
        limit: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProjectListResponse:
        """
        Lists application projects and deployed Thurgood apps for the authenticated
        organization. Use enrich=true to include additional hosting metadata for
        projects linked to Vercel.

        Args:
          enrich: Whether to include additional hosting metadata from Vercel

          limit: Maximum number of projects to return from each backing source

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/applications/v1/projects",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "enrich": enrich,
                        "limit": limit,
                    },
                    project_list_params.ProjectListParams,
                ),
            ),
            cast_to=ProjectListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        delete_from_hosting: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Soft-deletes an application project or deployed Thurgood app from Case.dev.

        By
        default it also removes the linked hosting project; set deleteFromHosting=false
        to keep the external hosting resources intact.

        Args:
          delete_from_hosting: Whether to also delete the linked hosting project. Defaults to true.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            path_template("/applications/v1/projects/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"delete_from_hosting": delete_from_hosting}, project_delete_params.ProjectDeleteParams
                ),
            ),
            cast_to=NoneType,
        )

    def create_deployment(
        self,
        id: str,
        *,
        environment_variables: Iterable[project_create_deployment_params.EnvironmentVariable] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Starts a new deployment for an existing project using its saved repository and
        hosting configuration. Any environment variables passed in the request are
        merged into the deployment workflow before the build starts.

        Args:
          environment_variables: Additional environment variables to set or update before deployment

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            path_template("/applications/v1/projects/{id}/deployments", id=id),
            body=maybe_transform(
                {"environment_variables": environment_variables},
                project_create_deployment_params.ProjectCreateDeploymentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def create_domain(
        self,
        id: str,
        *,
        domain: str,
        git_branch: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Add a custom domain to a project

        Args:
          domain: Domain name to add

          git_branch: Git branch to associate with this domain

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            path_template("/applications/v1/projects/{id}/domains", id=id),
            body=maybe_transform(
                {
                    "domain": domain,
                    "git_branch": git_branch,
                },
                project_create_domain_params.ProjectCreateDomainParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def create_env(
        self,
        id: str,
        *,
        key: str,
        target: List[Literal["production", "preview", "development"]],
        value: str,
        git_branch: str | Omit = omit,
        type: Literal["plain", "encrypted", "secret"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a new environment variable for a project

        Args:
          key: Environment variable name

          target: Deployment targets for this variable

          value: Environment variable value

          git_branch: Specific git branch (for preview deployments)

          type: Variable type

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            path_template("/applications/v1/projects/{id}/env", id=id),
            body=maybe_transform(
                {
                    "key": key,
                    "target": target,
                    "value": value,
                    "git_branch": git_branch,
                    "type": type,
                },
                project_create_env_params.ProjectCreateEnvParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete_domain(
        self,
        domain: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Remove a domain from a project

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not domain:
            raise ValueError(f"Expected a non-empty value for `domain` but received {domain!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            path_template("/applications/v1/projects/{id}/domains/{domain}", id=id, domain=domain),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete_env(
        self,
        env_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete an environment variable from a project

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not env_id:
            raise ValueError(f"Expected a non-empty value for `env_id` but received {env_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            path_template("/applications/v1/projects/{id}/env/{env_id}", id=id, env_id=env_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_runtime_logs(
        self,
        id: str,
        *,
        limit: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get runtime/function logs for a project

        Args:
          limit: Maximum number of logs to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/applications/v1/projects/{id}/runtime-logs", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"limit": limit}, project_get_runtime_logs_params.ProjectGetRuntimeLogsParams),
            ),
            cast_to=NoneType,
        )

    def list_deployments(
        self,
        id: str,
        *,
        limit: float | Omit = omit,
        state: str | Omit = omit,
        target: Literal["production", "staging"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Lists deployments for one project in the authenticated organization.

        If the
        hosting project has not been created yet, this endpoint returns an empty list
        with a progress message instead of failing.

        Args:
          limit: Maximum number of deployments to return

          state: Deployment state to filter by

          target: Deployment target to filter by

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/applications/v1/projects/{id}/deployments", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "state": state,
                        "target": target,
                    },
                    project_list_deployments_params.ProjectListDeploymentsParams,
                ),
            ),
            cast_to=NoneType,
        )

    def list_domains(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List all domains configured for a project

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/applications/v1/projects/{id}/domains", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list_env(
        self,
        id: str,
        *,
        decrypt: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List all environment variables for a project (values are hidden unless
        decrypt=true)

        Args:
          decrypt: Whether to decrypt and return values (requires appropriate permissions)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/applications/v1/projects/{id}/env", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"decrypt": decrypt}, project_list_env_params.ProjectListEnvParams),
            ),
            cast_to=NoneType,
        )


class AsyncProjectsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncProjectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncProjectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProjectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncProjectsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        git_repo: str,
        name: str,
        build_command: str | Omit = omit,
        environment_variables: Iterable[project_create_params.EnvironmentVariable] | Omit = omit,
        framework: str | Omit = omit,
        git_branch: str | Omit = omit,
        install_command: str | Omit = omit,
        output_directory: str | Omit = omit,
        root_directory: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Creates a new application project, validates GitHub access, provisions a default
        case.dev domain, and starts the deployment workflow. The initial response
        returns as soon as the workflow is queued so clients can poll for progress.

        Args:
          git_repo: GitHub repository URL or owner/repo identifier

          name: Human-readable project name

          build_command: Custom build command to override the framework default

          environment_variables: Environment variables to create before the first deployment

          framework: Framework preset for the hosting project, such as nextjs or remix

          git_branch: Git branch to deploy. Defaults to main.

          install_command: Custom install command to override the framework default

          output_directory: Build output directory relative to the project root

          root_directory: Repository subdirectory that contains the app to deploy

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/applications/v1/projects",
            body=await async_maybe_transform(
                {
                    "git_repo": git_repo,
                    "name": name,
                    "build_command": build_command,
                    "environment_variables": environment_variables,
                    "framework": framework,
                    "git_branch": git_branch,
                    "install_command": install_command,
                    "output_directory": output_directory,
                    "root_directory": root_directory,
                },
                project_create_params.ProjectCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Returns project details, domains, and recent deployment information for one
        application project or deployed Thurgood app. Use this endpoint when you need a
        single record with hosting metadata for a details view.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/applications/v1/projects/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        enrich: bool | Omit = omit,
        limit: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProjectListResponse:
        """
        Lists application projects and deployed Thurgood apps for the authenticated
        organization. Use enrich=true to include additional hosting metadata for
        projects linked to Vercel.

        Args:
          enrich: Whether to include additional hosting metadata from Vercel

          limit: Maximum number of projects to return from each backing source

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/applications/v1/projects",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "enrich": enrich,
                        "limit": limit,
                    },
                    project_list_params.ProjectListParams,
                ),
            ),
            cast_to=ProjectListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        delete_from_hosting: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Soft-deletes an application project or deployed Thurgood app from Case.dev.

        By
        default it also removes the linked hosting project; set deleteFromHosting=false
        to keep the external hosting resources intact.

        Args:
          delete_from_hosting: Whether to also delete the linked hosting project. Defaults to true.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            path_template("/applications/v1/projects/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"delete_from_hosting": delete_from_hosting}, project_delete_params.ProjectDeleteParams
                ),
            ),
            cast_to=NoneType,
        )

    async def create_deployment(
        self,
        id: str,
        *,
        environment_variables: Iterable[project_create_deployment_params.EnvironmentVariable] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Starts a new deployment for an existing project using its saved repository and
        hosting configuration. Any environment variables passed in the request are
        merged into the deployment workflow before the build starts.

        Args:
          environment_variables: Additional environment variables to set or update before deployment

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            path_template("/applications/v1/projects/{id}/deployments", id=id),
            body=await async_maybe_transform(
                {"environment_variables": environment_variables},
                project_create_deployment_params.ProjectCreateDeploymentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def create_domain(
        self,
        id: str,
        *,
        domain: str,
        git_branch: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Add a custom domain to a project

        Args:
          domain: Domain name to add

          git_branch: Git branch to associate with this domain

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            path_template("/applications/v1/projects/{id}/domains", id=id),
            body=await async_maybe_transform(
                {
                    "domain": domain,
                    "git_branch": git_branch,
                },
                project_create_domain_params.ProjectCreateDomainParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def create_env(
        self,
        id: str,
        *,
        key: str,
        target: List[Literal["production", "preview", "development"]],
        value: str,
        git_branch: str | Omit = omit,
        type: Literal["plain", "encrypted", "secret"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a new environment variable for a project

        Args:
          key: Environment variable name

          target: Deployment targets for this variable

          value: Environment variable value

          git_branch: Specific git branch (for preview deployments)

          type: Variable type

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            path_template("/applications/v1/projects/{id}/env", id=id),
            body=await async_maybe_transform(
                {
                    "key": key,
                    "target": target,
                    "value": value,
                    "git_branch": git_branch,
                    "type": type,
                },
                project_create_env_params.ProjectCreateEnvParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete_domain(
        self,
        domain: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Remove a domain from a project

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not domain:
            raise ValueError(f"Expected a non-empty value for `domain` but received {domain!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            path_template("/applications/v1/projects/{id}/domains/{domain}", id=id, domain=domain),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete_env(
        self,
        env_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete an environment variable from a project

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not env_id:
            raise ValueError(f"Expected a non-empty value for `env_id` but received {env_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            path_template("/applications/v1/projects/{id}/env/{env_id}", id=id, env_id=env_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_runtime_logs(
        self,
        id: str,
        *,
        limit: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get runtime/function logs for a project

        Args:
          limit: Maximum number of logs to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/applications/v1/projects/{id}/runtime-logs", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"limit": limit}, project_get_runtime_logs_params.ProjectGetRuntimeLogsParams
                ),
            ),
            cast_to=NoneType,
        )

    async def list_deployments(
        self,
        id: str,
        *,
        limit: float | Omit = omit,
        state: str | Omit = omit,
        target: Literal["production", "staging"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Lists deployments for one project in the authenticated organization.

        If the
        hosting project has not been created yet, this endpoint returns an empty list
        with a progress message instead of failing.

        Args:
          limit: Maximum number of deployments to return

          state: Deployment state to filter by

          target: Deployment target to filter by

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/applications/v1/projects/{id}/deployments", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "state": state,
                        "target": target,
                    },
                    project_list_deployments_params.ProjectListDeploymentsParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def list_domains(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List all domains configured for a project

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/applications/v1/projects/{id}/domains", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list_env(
        self,
        id: str,
        *,
        decrypt: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List all environment variables for a project (values are hidden unless
        decrypt=true)

        Args:
          decrypt: Whether to decrypt and return values (requires appropriate permissions)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/applications/v1/projects/{id}/env", id=id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"decrypt": decrypt}, project_list_env_params.ProjectListEnvParams),
            ),
            cast_to=NoneType,
        )


class ProjectsResourceWithRawResponse:
    def __init__(self, projects: ProjectsResource) -> None:
        self._projects = projects

        self.create = to_raw_response_wrapper(
            projects.create,
        )
        self.retrieve = to_raw_response_wrapper(
            projects.retrieve,
        )
        self.list = to_raw_response_wrapper(
            projects.list,
        )
        self.delete = to_raw_response_wrapper(
            projects.delete,
        )
        self.create_deployment = to_raw_response_wrapper(
            projects.create_deployment,
        )
        self.create_domain = to_raw_response_wrapper(
            projects.create_domain,
        )
        self.create_env = to_raw_response_wrapper(
            projects.create_env,
        )
        self.delete_domain = to_raw_response_wrapper(
            projects.delete_domain,
        )
        self.delete_env = to_raw_response_wrapper(
            projects.delete_env,
        )
        self.get_runtime_logs = to_raw_response_wrapper(
            projects.get_runtime_logs,
        )
        self.list_deployments = to_raw_response_wrapper(
            projects.list_deployments,
        )
        self.list_domains = to_raw_response_wrapper(
            projects.list_domains,
        )
        self.list_env = to_raw_response_wrapper(
            projects.list_env,
        )


class AsyncProjectsResourceWithRawResponse:
    def __init__(self, projects: AsyncProjectsResource) -> None:
        self._projects = projects

        self.create = async_to_raw_response_wrapper(
            projects.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            projects.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            projects.list,
        )
        self.delete = async_to_raw_response_wrapper(
            projects.delete,
        )
        self.create_deployment = async_to_raw_response_wrapper(
            projects.create_deployment,
        )
        self.create_domain = async_to_raw_response_wrapper(
            projects.create_domain,
        )
        self.create_env = async_to_raw_response_wrapper(
            projects.create_env,
        )
        self.delete_domain = async_to_raw_response_wrapper(
            projects.delete_domain,
        )
        self.delete_env = async_to_raw_response_wrapper(
            projects.delete_env,
        )
        self.get_runtime_logs = async_to_raw_response_wrapper(
            projects.get_runtime_logs,
        )
        self.list_deployments = async_to_raw_response_wrapper(
            projects.list_deployments,
        )
        self.list_domains = async_to_raw_response_wrapper(
            projects.list_domains,
        )
        self.list_env = async_to_raw_response_wrapper(
            projects.list_env,
        )


class ProjectsResourceWithStreamingResponse:
    def __init__(self, projects: ProjectsResource) -> None:
        self._projects = projects

        self.create = to_streamed_response_wrapper(
            projects.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            projects.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            projects.list,
        )
        self.delete = to_streamed_response_wrapper(
            projects.delete,
        )
        self.create_deployment = to_streamed_response_wrapper(
            projects.create_deployment,
        )
        self.create_domain = to_streamed_response_wrapper(
            projects.create_domain,
        )
        self.create_env = to_streamed_response_wrapper(
            projects.create_env,
        )
        self.delete_domain = to_streamed_response_wrapper(
            projects.delete_domain,
        )
        self.delete_env = to_streamed_response_wrapper(
            projects.delete_env,
        )
        self.get_runtime_logs = to_streamed_response_wrapper(
            projects.get_runtime_logs,
        )
        self.list_deployments = to_streamed_response_wrapper(
            projects.list_deployments,
        )
        self.list_domains = to_streamed_response_wrapper(
            projects.list_domains,
        )
        self.list_env = to_streamed_response_wrapper(
            projects.list_env,
        )


class AsyncProjectsResourceWithStreamingResponse:
    def __init__(self, projects: AsyncProjectsResource) -> None:
        self._projects = projects

        self.create = async_to_streamed_response_wrapper(
            projects.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            projects.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            projects.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            projects.delete,
        )
        self.create_deployment = async_to_streamed_response_wrapper(
            projects.create_deployment,
        )
        self.create_domain = async_to_streamed_response_wrapper(
            projects.create_domain,
        )
        self.create_env = async_to_streamed_response_wrapper(
            projects.create_env,
        )
        self.delete_domain = async_to_streamed_response_wrapper(
            projects.delete_domain,
        )
        self.delete_env = async_to_streamed_response_wrapper(
            projects.delete_env,
        )
        self.get_runtime_logs = async_to_streamed_response_wrapper(
            projects.get_runtime_logs,
        )
        self.list_deployments = async_to_streamed_response_wrapper(
            projects.list_deployments,
        )
        self.list_domains = async_to_streamed_response_wrapper(
            projects.list_domains,
        )
        self.list_env = async_to_streamed_response_wrapper(
            projects.list_env,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["InstanceDeleteResponse"]


class InstanceDeleteResponse(BaseModel):
    id: Optional[str] = None

    message: Optional[str] = None

    name: Optional[str] = None

    status: Optional[str] = None

    total_cost: Optional[str] = FieldInfo(alias="totalCost", default=None)

    total_runtime_seconds: Optional[int] = FieldInfo(alias="totalRuntimeSeconds", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Literal, Required, TypedDict

__all__ = ["V1CreateParams", "Message"]


class V1CreateParams(TypedDict, total=False):
    messages: Required[Iterable[Message]]
    """Conversation messages to extract memories from"""

    category: str
    """Custom category (e.g., "fact", "preference", "deadline")"""

    extraction_prompt: str
    """Optional custom prompt for fact extraction"""

    infer: bool
    """Whether to extract facts from messages (default: true)"""

    metadata: Dict[str, object]
    """Additional metadata (not indexed)"""

    tag_1: str
    """Generic indexed filter field 1 (you decide what it means)"""

    tag_10: str
    """Generic indexed filter field 10"""

    tag_11: str
    """Generic indexed filter field 11"""

    tag_12: str
    """Generic indexed filter field 12"""

    tag_2: str
    """Generic indexed filter field 2"""

    tag_3: str
    """Generic indexed filter field 3"""

    tag_4: str
    """Generic indexed filter field 4"""

    tag_5: str
    """Generic indexed filter field 5"""

    tag_6: str
    """Generic indexed filter field 6"""

    tag_7: str
    """Generic indexed filter field 7"""

    tag_8: str
    """Generic indexed filter field 8"""

    tag_9: str
    """Generic indexed filter field 9"""


class Message(TypedDict, total=False):
    content: Required[str]
    """Message content"""

    role: Required[Literal["user", "assistant", "system"]]
    """Message role"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AgentListParams"]


class AgentListParams(TypedDict, total=False):
    cursor: str
    """Pagination cursor (agent ID from previous page).

    Returns agents created before this agent.
    """

    limit: int
    """Maximum number of agents to return (default 50, max 250)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["RunWatchResponse"]


class RunWatchResponse(BaseModel):
    callback_url: Optional[str] = FieldInfo(alias="callbackUrl", default=None)

    ok: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ProjectCreateBranchParams"]


class ProjectCreateBranchParams(TypedDict, total=False):
    name: Required[str]
    """Branch name (letters, numbers, hyphens, underscores only)"""

    parent_branch_id: Annotated[str, PropertyInfo(alias="parentBranchId")]
    """Parent branch ID to clone from (defaults to main branch)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from ...._models import BaseModel

__all__ = ["LogExportResponse"]


class LogExportResponse(BaseModel):
    data: Optional[List[Dict[str, object]]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NoneType, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.voice import transcription_create_params
from ..._base_client import make_request_options
from ...types.voice.transcription_create_response import TranscriptionCreateResponse
from ...types.voice.transcription_retrieve_response import TranscriptionRetrieveResponse

__all__ = ["TranscriptionResource", "AsyncTranscriptionResource"]


class TranscriptionResource(SyncAPIResource):
    """Audio transcription and text-to-speech"""

    @cached_property
    def with_raw_response(self) -> TranscriptionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return TranscriptionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TranscriptionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return TranscriptionResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        audio_url: str | Omit = omit,
        auto_highlights: bool | Omit = omit,
        boost_param: Literal["low", "default", "high"] | Omit = omit,
        content_safety_labels: bool | Omit = omit,
        format: Literal["json", "text"] | Omit = omit,
        format_text: bool | Omit = omit,
        language_code: str | Omit = omit,
        language_detection: bool | Omit = omit,
        object_id: str | Omit = omit,
        punctuate: bool | Omit = omit,
        speaker_labels: bool | Omit = omit,
        speakers_expected: int | Omit = omit,
        speech_models: SequenceNotStr[str] | Omit = omit,
        vault_id: str | Omit = omit,
        word_boost: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TranscriptionCreateResponse:
        """Creates an asynchronous transcription job for audio files.

        Supports two modes:

        **Vault-based (recommended)**: Pass `vault_id` and `object_id` to transcribe
        audio from your vault. The transcript will automatically be saved back to the
        vault when complete.

        **Direct URL (legacy)**: Pass `audio_url` for direct transcription without
        automatic storage.

        Args:
          audio_url: URL of the audio file to transcribe (legacy mode, no auto-storage)

          auto_highlights: Automatically extract key phrases and topics

          boost_param: How much to boost custom vocabulary

          content_safety_labels: Enable content moderation and safety labeling

          format: Output format for the transcript when using vault mode

          format_text: Format text with proper capitalization

          language_code: Language code (e.g., 'en_us', 'es', 'fr'). If not specified, language will be
              auto-detected

          language_detection: Enable automatic language detection

          object_id: Object ID of the audio file in the vault (use with vault_id)

          punctuate: Add punctuation to the transcript

          speaker_labels: Enable speaker identification and labeling

          speakers_expected: Expected number of speakers (improves accuracy when known)

          speech_models: Priority-ordered speech models to use

          vault_id: Vault ID containing the audio file (use with object_id)

          word_boost: Custom vocabulary words to boost (e.g., legal terms)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/voice/transcription",
            body=maybe_transform(
                {
                    "audio_url": audio_url,
                    "auto_highlights": auto_highlights,
                    "boost_param": boost_param,
                    "content_safety_labels": content_safety_labels,
                    "format": format,
                    "format_text": format_text,
                    "language_code": language_code,
                    "language_detection": language_detection,
                    "object_id": object_id,
                    "punctuate": punctuate,
                    "speaker_labels": speaker_labels,
                    "speakers_expected": speakers_expected,
                    "speech_models": speech_models,
                    "vault_id": vault_id,
                    "word_boost": word_boost,
                },
                transcription_create_params.TranscriptionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TranscriptionRetrieveResponse:
        """Retrieve the status and result of an audio transcription job.

        For vault-based
        jobs, returns status and result_object_id when complete. For legacy direct URL
        jobs, returns the full transcription data.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            path_template("/voice/transcription/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionRetrieveResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Deletes a transcription job.

        For managed vault jobs (tr\\__\\**), also removes local
        job records and managed transcript result objects. Idempotent: returns success
        if already deleted.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            path_template("/voice/transcription/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncTranscriptionResource(AsyncAPIResource):
    """Audio transcription and text-to-speech"""

    @cached_property
    def with_raw_response(self) -> AsyncTranscriptionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTranscriptionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTranscriptionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncTranscriptionResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        audio_url: str | Omit = omit,
        auto_highlights: bool | Omit = omit,
        boost_param: Literal["low", "default", "high"] | Omit = omit,
        content_safety_labels: bool | Omit = omit,
        format: Literal["json", "text"] | Omit = omit,
        format_text: bool | Omit = omit,
        language_code: str | Omit = omit,
        language_detection: bool | Omit = omit,
        object_id: str | Omit = omit,
        punctuate: bool | Omit = omit,
        speaker_labels: bool | Omit = omit,
        speakers_expected: int | Omit = omit,
        speech_models: SequenceNotStr[str] | Omit = omit,
        vault_id: str | Omit = omit,
        word_boost: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TranscriptionCreateResponse:
        """Creates an asynchronous transcription job for audio files.

        Supports two modes:

        **Vault-based (recommended)**: Pass `vault_id` and `object_id` to transcribe
        audio from your vault. The transcript will automatically be saved back to the
        vault when complete.

        **Direct URL (legacy)**: Pass `audio_url` for direct transcription without
        automatic storage.

        Args:
          audio_url: URL of the audio file to transcribe (legacy mode, no auto-storage)

          auto_highlights: Automatically extract key phrases and topics

          boost_param: How much to boost custom vocabulary

          content_safety_labels: Enable content moderation and safety labeling

          format: Output format for the transcript when using vault mode

          format_text: Format text with proper capitalization

          language_code: Language code (e.g., 'en_us', 'es', 'fr'). If not specified, language will be
              auto-detected

          language_detection: Enable automatic language detection

          object_id: Object ID of the audio file in the vault (use with vault_id)

          punctuate: Add punctuation to the transcript

          speaker_labels: Enable speaker identification and labeling

          speakers_expected: Expected number of speakers (improves accuracy when known)

          speech_models: Priority-ordered speech models to use

          vault_id: Vault ID containing the audio file (use with object_id)

          word_boost: Custom vocabulary words to boost (e.g., legal terms)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/voice/transcription",
            body=await async_maybe_transform(
                {
                    "audio_url": audio_url,
                    "auto_highlights": auto_highlights,
                    "boost_param": boost_param,
                    "content_safety_labels": content_safety_labels,
                    "format": format,
                    "format_text": format_text,
                    "language_code": language_code,
                    "language_detection": language_detection,
                    "object_id": object_id,
                    "punctuate": punctuate,
                    "speaker_labels": speaker_labels,
                    "speakers_expected": speakers_expected,
                    "speech_models": speech_models,
                    "vault_id": vault_id,
                    "word_boost": word_boost,
                },
                transcription_create_params.TranscriptionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TranscriptionRetrieveResponse:
        """Retrieve the status and result of an audio transcription job.

        For vault-based
        jobs, returns status and result_object_id when complete. For legacy direct URL
        jobs, returns the full transcription data.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            path_template("/voice/transcription/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionRetrieveResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Deletes a transcription job.

        For managed vault jobs (tr\\__\\**), also removes local
        job records and managed transcript result objects. Idempotent: returns success
        if already deleted.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            path_template("/voice/transcription/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class TranscriptionResourceWithRawResponse:
    def __init__(self, transcription: TranscriptionResource) -> None:
        self._transcription = transcription

        self.create = to_raw_response_wrapper(
            transcription.create,
        )
        self.retrieve = to_raw_response_wrapper(
            transcription.retrieve,
        )
        self.delete = to_raw_response_wrapper(
            transcription.delete,
        )


class AsyncTranscriptionResourceWithRawResponse:
    def __init__(self, transcription: AsyncTranscriptionResource) -> None:
        self._transcription = transcription

        self.create = async_to_raw_response_wrapper(
            transcription.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            transcription.retrieve,
        )
        self.delete = async_to_raw_response_wrapper(
            transcription.delete,
        )


class TranscriptionResourceWithStreamingResponse:
    def __init__(self, transcription: TranscriptionResource) -> None:
        self._transcription = transcription

        self.create = to_streamed_response_wrapper(
            transcription.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            transcription.retrieve,
        )
        self.delete = to_streamed_response_wrapper(
            transcription.delete,
        )


class AsyncTranscriptionResourceWithStreamingResponse:
    def __init__(self, transcription: AsyncTranscriptionResource) -> None:
        self._transcription = transcription

        self.create = async_to_streamed_response_wrapper(
            transcription.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            transcription.retrieve,
        )
        self.delete = async_to_streamed_response_wrapper(
            transcription.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .inbox_create_params import InboxCreateParams as InboxCreateParams
from .inbox_set_policy_params import InboxSetPolicyParams as InboxSetPolicyParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VaultSearchResponse", "Chunk", "Source"]


class Chunk(BaseModel):
    chunk_index: Optional[int] = None
    """Index of the chunk within the document (0-based)"""

    distance: Optional[float] = None
    """Vector similarity distance (lower is more similar)"""

    object_id: Optional[str] = None
    """ID of the source document"""

    page_end: Optional[int] = None
    """PDF page number where the chunk ends (1-indexed).

    Null for non-PDF documents or documents ingested before page tracking was added.
    """

    page_start: Optional[int] = None
    """PDF page number where the chunk begins (1-indexed).

    Null for non-PDF documents or documents ingested before page tracking was added.
    """

    score: Optional[float] = None
    """Relevance score (deprecated, use distance or hybridScore)"""

    source: Optional[str] = None
    """Source identifier (deprecated, use object_id)"""

    text: Optional[str] = None
    """Preview of the chunk text (up to 500 characters)"""

    word_end_index: Optional[int] = None
    """Ending word index (0-based) in the OCR word list.

    Use with GET /vault/:id/objects/:objectId/ocr-words to retrieve bounding boxes
    for highlighting.
    """

    word_start_index: Optional[int] = None
    """Starting word index (0-based) in the OCR word list.

    Use with GET /vault/:id/objects/:objectId/ocr-words to retrieve bounding boxes
    for highlighting.
    """


class Source(BaseModel):
    id: Optional[str] = None

    chunk_count: Optional[int] = FieldInfo(alias="chunkCount", default=None)

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)

    filename: Optional[str] = None

    ingestion_completed_at: Optional[datetime] = FieldInfo(alias="ingestionCompletedAt", default=None)

    page_count: Optional[int] = FieldInfo(alias="pageCount", default=None)

    text_length: Optional[int] = FieldInfo(alias="textLength", default=None)


class VaultSearchResponse(BaseModel):
    chunks: Optional[List[Chunk]] = None
    """Relevant text chunks with similarity scores and page locations"""

    method: Optional[str] = None
    """Search method used"""

    query: Optional[str] = None
    """Original search query"""

    response: Optional[str] = None
    """AI-generated answer based on search results (for global/entity methods)"""

    sources: Optional[List[Source]] = None

    vault_id: Optional[str] = None
    """ID of the searched vault"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["InboxCreateParams"]


class InboxCreateParams(TypedDict, total=False):
    address: str

    display_name: Annotated[str, PropertyInfo(alias="displayName")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, TypedDict

from ..._types import SequenceNotStr

__all__ = ["BoostListExtractParams"]


class BoostListExtractParams(TypedDict, total=False):
    categories: List[Literal["person", "organization", "legal_term", "medical", "citation", "email"]]
    """Optional filter for entity categories to extract"""

    object_ids: SequenceNotStr[str]
    """Object IDs of documents to extract entities from (PDFs, text files)"""

    text: str
    """Raw text input for entity extraction (alternative to vault documents)"""

    vault_id: str
    """Vault ID containing the source documents (use with object_ids)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["ObjectDeleteResponse", "DeletedObject"]


class DeletedObject(BaseModel):
    id: Optional[str] = None
    """Deleted object ID"""

    filename: Optional[str] = None
    """Original filename"""

    size_bytes: Optional[int] = FieldInfo(alias="sizeBytes", default=None)
    """Size of deleted file in bytes"""

    vectors_deleted: Optional[int] = FieldInfo(alias="vectorsDeleted", default=None)
    """Number of vectors deleted"""


class ObjectDeleteResponse(BaseModel):
    deleted_object: Optional[DeletedObject] = FieldInfo(alias="deletedObject", default=None)

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .group_create_params import GroupCreateParams as GroupCreateParams
from .group_update_params import GroupUpdateParams as GroupUpdateParams
from .memory_create_params import MemoryCreateParams as MemoryCreateParams
from .memory_list_response import MemoryListResponse as MemoryListResponse
from .memory_search_params import MemorySearchParams as MemorySearchParams
from .memory_update_params import MemoryUpdateParams as MemoryUpdateParams
from .object_delete_params import ObjectDeleteParams as ObjectDeleteParams
from .object_list_response import ObjectListResponse as ObjectListResponse
from .object_update_params import ObjectUpdateParams as ObjectUpdateParams
from .graphrag_init_response import GraphragInitResponse as GraphragInitResponse
from .memory_create_response import MemoryCreateResponse as MemoryCreateResponse
from .memory_search_response import MemorySearchResponse as MemorySearchResponse
from .multipart_abort_params import MultipartAbortParams as MultipartAbortParams
from .object_delete_response import ObjectDeleteResponse as ObjectDeleteResponse
from .object_update_response import ObjectUpdateResponse as ObjectUpdateResponse
from .object_get_text_response import ObjectGetTextResponse as ObjectGetTextResponse
from .object_retrieve_response import ObjectRetrieveResponse as ObjectRetrieveResponse
from .graphrag_get_stats_response import GraphragGetStatsResponse as GraphragGetStatsResponse
from .object_get_ocr_words_params import ObjectGetOcrWordsParams as ObjectGetOcrWordsParams
from .object_get_ocr_words_response import ObjectGetOcrWordsResponse as ObjectGetOcrWordsResponse
from .multipart_get_part_urls_params import MultipartGetPartURLsParams as MultipartGetPartURLsParams
from .graphrag_process_object_response import GraphragProcessObjectResponse as GraphragProcessObjectResponse
from .multipart_get_part_urls_response import MultipartGetPartURLsResponse as MultipartGetPartURLsResponse
from .object_get_summarize_job_response import ObjectGetSummarizeJobResponse as ObjectGetSummarizeJobResponse
from .object_create_presigned_url_params import ObjectCreatePresignedURLParams as ObjectCreatePresignedURLParams
from .object_create_presigned_url_response import ObjectCreatePresignedURLResponse as ObjectCreatePresignedURLResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SecretCreateParams"]


class SecretCreateParams(TypedDict, total=False):
    name: Required[str]
    """Unique name for the secret group.

    Must contain only letters, numbers, hyphens, and underscores.
    """

    description: str
    """Optional description of the secret group's purpose"""

    env: str
    """Environment name where the secret group will be created.

    Uses default environment if not specified.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_process_params import V1ProcessParams as V1ProcessParams
from .v1_process_response import V1ProcessResponse as V1ProcessResponse
from .v1_retrieve_response import V1RetrieveResponse as V1RetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["WorkItemDecideParams"]


class WorkItemDecideParams(TypedDict, total=False):
    id: Required[str]

    decision: Required[Literal["approve", "revise", "block", "reassign"]]

    agent_type_id: Optional[str]

    metadata: Dict[str, object]

    reason: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["AgentDeleteResponse"]


class AgentDeleteResponse(BaseModel):
    ok: Optional[bool] = None
